@@ -9,7 +9,8 @@ TYPES = set(['artifact', 'basic', 'creature', 'enchantment', 'instant', 'land',
 
 COLORS = {'w': 'W', 'u': 'U', 'b': 'B', 'r': 'R', 'g': 'G', 'c': 'C'}
 
-RARITY_NAMES = ['Mythic Rare', 'Common', 'Uncommon', 'Rare']
+RARITY_NAMES = set(['Mythic Rare', 'Common', 'Uncommon', 'Rare', 'Land',
+                    'Special', 'Promo'])
 
 RARITIES = {
     'c': 'C',
